%% Parameter Sweep of ODEs
% This is a parameter sweep study of a 2nd order ODE system.
%
%   m*X'' + b*X' + k*X = 0
%
% We solve the ODE for a time span of 0 to 25 seconds, with initial
% conditions X(0) = 0 and X'(0) = 1. We sweep the parameters "b" and "k"
% and record the peak values of X for each condition. At the end, we plot a
% surface of the results.
%
% In this version of the implementation only matlabpool and parfor are used to
% distribute the load. Since this script is to be called through batch,
% visualization is not done here.
%

% Copyright 2009 The MathWorks, Inc.

% Modified by R. Leidl 2013, CvO University of Oldenburg
% File has been provided during the workshop held on Feb 19. 2013

%% Initialize Problem
m     =         5;  % mass
bVals = 0.1:.1:15;  % damping values (step .1)
kVals = 1.5:.1:15;  % stiffness values (step .1) damping
[kGrid, bGrid] = meshgrid(bVals, kVals);
peakVals = nan(size(kGrid));

%% Parameter Sweep
tic;

parfor idx = 1:numel(kGrid)
  % Solve ODE
  [T,Y] = ode45(@(t,y) odesystem(t, y, m, bGrid(idx), kGrid(idx)), ...
    [0, 25], ...  % simulate for 25 seconds
    [0, 1]);      % initial conditions
 
  % Determine peak value
  peakVals(idx) = max(Y(:,1));
end

t1 = toc;
